package javax.naming;

import javax.naming.spi.NamingManager;
import com.sun.naming.internal.ResourceManager;
import java.util.Hashtable;

public class InitialContext implements Context
{
    protected Hashtable<Object, Object> myProps;
    protected Context defaultInitCtx;
    protected boolean gotDefault;
    
    protected InitialContext(boolean b) throws NamingException {
        this.myProps = null;
        this.defaultInitCtx = null;
        this.gotDefault = false;
        if (!b) {
            this.init(null);
        }
    }
    
    public InitialContext() throws NamingException {
        this.myProps = null;
        this.defaultInitCtx = null;
        this.gotDefault = false;
        this.init(null);
    }
    
    public InitialContext(Hashtable<?, ?> hashtable) throws NamingException {
        this.myProps = null;
        this.defaultInitCtx = null;
        this.gotDefault = false;
        if (hashtable != null) {
            hashtable = (Hashtable)hashtable.clone();
        }
        this.init(hashtable);
    }
    
    protected void init(Hashtable<?, ?> env) throws NamingException {
        this.myProps = ResourceManager.getInitialEnvironment(env);
        if (this.myProps.get("java.naming.factory.initial") != null) {
            this.getDefaultInitCtx();
        }
    }
    
    public static <T> T doLookup(Name name) throws NamingException {
        return new InitialContext().lookup(name);
    }
    
    public static <T> T doLookup(String s) throws NamingException {
        return new InitialContext().lookup(s);
    }
    
    private static String getURLScheme(String s) {
        int index = s.indexOf(58);
        int index2 = s.indexOf(47);
        if (index > 0 && (index2 == -1 || index < index2)) {
            return s.substring(0, index);
        }
        return null;
    }
    
    protected Context getDefaultInitCtx() throws NamingException {
        if (!this.gotDefault) {
            this.defaultInitCtx = NamingManager.getInitialContext(this.myProps);
            this.gotDefault = true;
        }
        if (this.defaultInitCtx == null) {
            throw new NoInitialContextException();
        }
        return this.defaultInitCtx;
    }
    
    protected Context getURLOrDefaultInitCtx(String s) throws NamingException {
        if (NamingManager.hasInitialContextFactoryBuilder()) {
            return this.getDefaultInitCtx();
        }
        String urlScheme = getURLScheme(s);
        if (urlScheme != null) {
            Context urlContext = NamingManager.getURLContext(urlScheme, this.myProps);
            if (urlContext != null) {
                return urlContext;
            }
        }
        return this.getDefaultInitCtx();
    }
    
    protected Context getURLOrDefaultInitCtx(Name name) throws NamingException {
        if (NamingManager.hasInitialContextFactoryBuilder()) {
            return this.getDefaultInitCtx();
        }
        if (name.size() > 0) {
            String urlScheme = getURLScheme(name.get(0));
            if (urlScheme != null) {
                Context urlContext = NamingManager.getURLContext(urlScheme, this.myProps);
                if (urlContext != null) {
                    return urlContext;
                }
            }
        }
        return this.getDefaultInitCtx();
    }
    
    @Override
    public Object lookup(String s) throws NamingException {
        return this.getURLOrDefaultInitCtx(s).lookup(s);
    }
    
    @Override
    public Object lookup(Name name) throws NamingException {
        return this.getURLOrDefaultInitCtx(name).lookup(name);
    }
    
    @Override
    public void bind(String s, Object o) throws NamingException {
        this.getURLOrDefaultInitCtx(s).bind(s, o);
    }
    
    @Override
    public void bind(Name name, Object o) throws NamingException {
        this.getURLOrDefaultInitCtx(name).bind(name, o);
    }
    
    @Override
    public void rebind(String s, Object o) throws NamingException {
        this.getURLOrDefaultInitCtx(s).rebind(s, o);
    }
    
    @Override
    public void rebind(Name name, Object o) throws NamingException {
        this.getURLOrDefaultInitCtx(name).rebind(name, o);
    }
    
    @Override
    public void unbind(String s) throws NamingException {
        this.getURLOrDefaultInitCtx(s).unbind(s);
    }
    
    @Override
    public void unbind(Name name) throws NamingException {
        this.getURLOrDefaultInitCtx(name).unbind(name);
    }
    
    @Override
    public void rename(String s, String s2) throws NamingException {
        this.getURLOrDefaultInitCtx(s).rename(s, s2);
    }
    
    @Override
    public void rename(Name name, Name name2) throws NamingException {
        this.getURLOrDefaultInitCtx(name).rename(name, name2);
    }
    
    @Override
    public NamingEnumeration<NameClassPair> list(String s) throws NamingException {
        return this.getURLOrDefaultInitCtx(s).list(s);
    }
    
    @Override
    public NamingEnumeration<NameClassPair> list(Name name) throws NamingException {
        return this.getURLOrDefaultInitCtx(name).list(name);
    }
    
    @Override
    public NamingEnumeration<Binding> listBindings(String s) throws NamingException {
        return this.getURLOrDefaultInitCtx(s).listBindings(s);
    }
    
    @Override
    public NamingEnumeration<Binding> listBindings(Name name) throws NamingException {
        return this.getURLOrDefaultInitCtx(name).listBindings(name);
    }
    
    @Override
    public void destroySubcontext(String s) throws NamingException {
        this.getURLOrDefaultInitCtx(s).destroySubcontext(s);
    }
    
    @Override
    public void destroySubcontext(Name name) throws NamingException {
        this.getURLOrDefaultInitCtx(name).destroySubcontext(name);
    }
    
    @Override
    public Context createSubcontext(String s) throws NamingException {
        return this.getURLOrDefaultInitCtx(s).createSubcontext(s);
    }
    
    @Override
    public Context createSubcontext(Name name) throws NamingException {
        return this.getURLOrDefaultInitCtx(name).createSubcontext(name);
    }
    
    @Override
    public Object lookupLink(String s) throws NamingException {
        return this.getURLOrDefaultInitCtx(s).lookupLink(s);
    }
    
    @Override
    public Object lookupLink(Name name) throws NamingException {
        return this.getURLOrDefaultInitCtx(name).lookupLink(name);
    }
    
    @Override
    public NameParser getNameParser(String s) throws NamingException {
        return this.getURLOrDefaultInitCtx(s).getNameParser(s);
    }
    
    @Override
    public NameParser getNameParser(Name name) throws NamingException {
        return this.getURLOrDefaultInitCtx(name).getNameParser(name);
    }
    
    @Override
    public String composeName(String s, String s2) throws NamingException {
        return s;
    }
    
    @Override
    public Name composeName(Name name, Name name2) throws NamingException {
        return (Name)name.clone();
    }
    
    @Override
    public Object addToEnvironment(String key, Object value) throws NamingException {
        this.myProps.put(key, value);
        return this.getDefaultInitCtx().addToEnvironment(key, value);
    }
    
    @Override
    public Object removeFromEnvironment(String key) throws NamingException {
        this.myProps.remove(key);
        return this.getDefaultInitCtx().removeFromEnvironment(key);
    }
    
    @Override
    public Hashtable<?, ?> getEnvironment() throws NamingException {
        return this.getDefaultInitCtx().getEnvironment();
    }
    
    @Override
    public void close() throws NamingException {
        this.myProps = null;
        if (this.defaultInitCtx != null) {
            this.defaultInitCtx.close();
            this.defaultInitCtx = null;
        }
        this.gotDefault = false;
    }
    
    @Override
    public String getNameInNamespace() throws NamingException {
        return this.getDefaultInitCtx().getNameInNamespace();
    }
}
